import type { DocumentNode, ExecutionResult, GraphQLSchema } from 'graphql';
import { Anyware } from '../../lib/anyware/__.js';
import { type StandardScalarVariables } from '../../lib/graphql.js';
import type { Schema } from '../1_Schema/__.js';
import type { GraphQLObjectSelection } from '../3_SelectionSet/encode.js';
import type { GraffleExecutionResultVar } from '../6_client/client.js';
import type { Config } from '../6_client/Settings/Config.js';
import type { ContextInterfaceRaw, ContextInterfaceTyped, InterfaceRaw, InterfaceTyped, TransportHttp, TransportMemory } from './types.js';
type InterfaceInput<TypedProperties = {}, RawProperties = {}> = ({
    interface: InterfaceTyped;
    context: ContextInterfaceTyped;
    rootTypeName: Schema.RootTypeName;
} & TypedProperties) | ({
    interface: InterfaceRaw;
    context: ContextInterfaceRaw;
} & RawProperties);
type TransportInput<$Config extends Config, $HttpProperties = {}, $MemoryProperties = {}> = (TransportHttp extends $Config['transport'] ? ({
    transport: TransportHttp;
    transportConstructorConfig: {
        headers?: HeadersInit;
    };
} & $HttpProperties) : never) | (TransportMemory extends $Config['transport'] ? ({
    transport: TransportMemory;
} & $MemoryProperties) : never);
export declare const hookNamesOrderedBySequence: readonly ["encode", "pack", "exchange", "unpack", "decode"];
export type HookSequence = typeof hookNamesOrderedBySequence;
export type HookDefEncode<$Config extends Config> = {
    input: InterfaceInput<{
        selection: GraphQLObjectSelection;
    }, {
        document: string | DocumentNode;
        variables?: StandardScalarVariables;
        operationName?: string;
    }> & TransportInput<$Config, {
        schema: string | URL;
    }, {
        schema: GraphQLSchema;
    }>;
    slots: {
        /**
         * Create the value that will be used as the HTTP body for the sent GraphQL request.
         */
        body: (input: {
            query: string;
            variables?: StandardScalarVariables;
            operationName?: string;
        }) => BodyInit;
    };
};
export type HookDefPack<$Config extends Config> = {
    input: InterfaceInput & TransportInput<$Config, {
        url: string | URL;
        headers?: HeadersInit;
        body: BodyInit;
    }, {
        schema: GraphQLSchema;
        query: string;
        variables?: StandardScalarVariables;
        operationName?: string;
    }>;
};
export type RequestInput = {
    url: string | URL;
    method: 'get' | 'post' | 'put' | 'delete' | 'patch' | 'head' | 'options' | 'trace' | 'GET' | 'POST' | 'PUT' | 'DELETE' | 'PATCH' | 'HEAD' | 'OPTIONS' | 'TRACE';
    headers?: HeadersInit;
    body: BodyInit;
};
export type HookDefExchange<$Config extends Config> = {
    slots: {
        fetch: typeof fetch;
    };
    input: InterfaceInput & TransportInput<$Config, {
        request: RequestInput;
    }, {
        schema: GraphQLSchema;
        query: string | DocumentNode;
        variables?: StandardScalarVariables;
        operationName?: string;
    }>;
};
export type HookDefUnpack<$Config extends Config> = {
    input: InterfaceInput & TransportInput<$Config, {
        response: Response;
    }, {
        result: ExecutionResult;
    }>;
};
export type HookDefDecode<$Config extends Config> = {
    input: {
        result: ExecutionResult;
    } & InterfaceInput & TransportInput<$Config, {
        response: Response;
    }>;
};
export type HookMap<$Config extends Config = Config> = {
    encode: HookDefEncode<$Config>;
    pack: HookDefPack<$Config>;
    exchange: HookDefExchange<$Config>;
    unpack: HookDefUnpack<$Config>;
    decode: HookDefDecode<$Config>;
};
export declare const anyware: Anyware.Builder<Anyware.Core<readonly ["encode", "pack", "exchange", "unpack", "decode"], HookMap<Config>, ExecutionResult<import("graphql/jsutils/ObjMap.js").ObjMap<unknown>, import("graphql/jsutils/ObjMap.js").ObjMap<unknown>>>>;
export type Core<$Config extends Config = Config> = Anyware.Core<HookSequence, HookMap<$Config>, GraffleExecutionResultVar<$Config>>;
export {};
//# sourceMappingURL=core.d.ts.map